@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import logging
+import os
 
 from .provider import provider
 
@@ -18,10 +19,14 @@ def enable(app):
         from .nem import Nem
 
         nem = Nem(app)
+        nem.initialize()
         item = app.pvd_uimgr.create_item(
             name=provider.identifier,
             text='网易云音乐',
             desc='点击可以登录',
+            colorful_svg=os.path.abspath(
+                os.path.join(os.path.dirname(__file__), 'assets', 'icon.svg')
+            ),
         )
         item.clicked.connect(nem.ready_to_login)
         nem._pm = item
